.. Copyright (C) 2015-2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`PostgreSQL`__ is a popular relational open source database. The
``debops.postgresql`` role can be used to create and manage PostgreSQL roles
and databases on local or remote PostgreSQL servers.

To manage the PostgreSQL server itself, you will need to use
``debops.postgresql_server`` role.

.. __: https://www.postgresql.org/
